==> zio-aws-pinpointemail_2.12-5.17.151.2-sources.jar: zio/aws/pinpointemail/model/ListEmailIdentitiesRequest.scala <==
package zio.aws.pinpointemail.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpointemail.model.primitives.{MaxItems, NextToken}
import scala.jdk.CollectionConverters._
final case class ListEmailIdentitiesRequest(
    nextToken: Option[NextToken] = None,
    pageSize: Option[MaxItems] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest = {
    import ListEmailIdentitiesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(pageSize.map(value => MaxItems.unwrap(value): Integer))(
        _.pageSize
      )
      .build()
  }
  def asReadOnly
      : zio.aws.pinpointemail.model.ListEmailIdentitiesRequest.ReadOnly =
    zio.aws.pinpointemail.model.ListEmailIdentitiesRequest.wrap(buildAwsValue())
}
object ListEmailIdentitiesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpointemail.model.ListEmailIdentitiesRequest =
      zio.aws.pinpointemail.model.ListEmailIdentitiesRequest(
        nextToken.map(value => value),
        pageSize.map(value => value)
      )
    def nextToken: Option[NextToken]
    def pageSize: Option[MaxItems]
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getPageSize: ZIO[Any, AwsError, MaxItems] =
      AwsError.unwrapOptionField("pageSize", pageSize)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest
  ) extends zio.aws.pinpointemail.model.ListEmailIdentitiesRequest.ReadOnly {
    override val nextToken: Option[NextToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.pinpointemail.model.primitives.NextToken(value))
    override val pageSize: Option[MaxItems] = scala
      .Option(impl.pageSize())
      .map(value => zio.aws.pinpointemail.model.primitives.MaxItems(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest
  ): zio.aws.pinpointemail.model.ListEmailIdentitiesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpointemail_2.12-5.20.42.1-sources.jar: zio/aws/pinpointemail/model/ListEmailIdentitiesRequest.scala <==
package zio.aws.pinpointemail.model
import zio.prelude.data.Optional
import zio.aws.pinpointemail.model.primitives.{MaxItems, NextToken}
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListEmailIdentitiesRequest(
    nextToken: Optional[NextToken] = Optional.Absent,
    pageSize: Optional[MaxItems] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest = {
    import ListEmailIdentitiesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest
      .builder()
      .optionallyWith(
        nextToken.map(value => NextToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .optionallyWith(pageSize.map(value => MaxItems.unwrap(value): Integer))(
        _.pageSize
      )
      .build()
  }
  def asReadOnly
      : zio.aws.pinpointemail.model.ListEmailIdentitiesRequest.ReadOnly =
    zio.aws.pinpointemail.model.ListEmailIdentitiesRequest.wrap(buildAwsValue())
}
object ListEmailIdentitiesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpointemail.model.ListEmailIdentitiesRequest =
      zio.aws.pinpointemail.model.ListEmailIdentitiesRequest(
        nextToken.map(value => value),
        pageSize.map(value => value)
      )
    def nextToken: Optional[NextToken]
    def pageSize: Optional[MaxItems]
    def getNextToken: ZIO[Any, AwsError, NextToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
    def getPageSize: ZIO[Any, AwsError, MaxItems] =
      AwsError.unwrapOptionField("pageSize", pageSize)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest
  ) extends zio.aws.pinpointemail.model.ListEmailIdentitiesRequest.ReadOnly {
    override val nextToken: Optional[NextToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.pinpointemail.model.primitives.NextToken(value))
    override val pageSize: Optional[MaxItems] = zio.aws.core.internal
      .optionalFromNullable(impl.pageSize())
      .map(value => zio.aws.pinpointemail.model.primitives.MaxItems(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpointemail.model.ListEmailIdentitiesRequest
  ): zio.aws.pinpointemail.model.ListEmailIdentitiesRequest.ReadOnly =
    new Wrapper(impl)
}
